@@ -8,7 +8,7 @@ import lurklite.tempcmds as tempcmds
 static_cmds = None
 
 # The version
-miniirc.version = f'lurklite v0.4.17 (powered by {miniirc.version})'
+miniirc.version = f'lurklite v0.4.18 (powered by {miniirc.version})'
 
 # Throw errors
 class BotError(Exception):
@@ -51,7 +51,12 @@ class Bot:
         res = set()
         for victim in self.config[section].get('ignored', '').split(','):
             victim = victim.strip()
-            res.add(re.escape(victim).lower().replace('\\*', '.*'))
+            if victim:
+                res.add(re.escape(victim).lower().replace('\\*', '.*'))
+
+        regex_ignore = self.config[section].get('regex_ignore', '').strip()
+        if regex_ignore:
+            res.add(regex_ignore)
         return re.compile('^(' + ')|('.join(res) + ')$')
 
     # Add extra items
